<?php
declare(strict_types = 1);

namespace App\Http\Controllers\Auth;

use App\Exceptions\GeneralException;
use App\Http\Controllers\Controller;
use App\Http\Logics\Auth\AuthLogic;
use App\Http\Requests\Auth\LoginRequest;
use Illuminate\Auth\AuthenticationException;
use Illuminate\Http\JsonResponse;
use Symfony\Component\HttpFoundation\Response;

class AuthController extends Controller
{
    protected AuthLogic $auth_logic;

    /**
     * AuthController constructor.
     */
    public function __construct()
    {
        $this->auth_logic = new AuthLogic();
    }

    /**
     * 登录接口
     * @param LoginRequest $request
     * @return JsonResponse
     * @throws GeneralException
     */
    public function login(LoginRequest $request): JsonResponse
    {
        $response = $this->auth_logic->login($request->code);

        return jsonResponse(Response::HTTP_OK, 'success.', $response);
    }

    /**
     * 未登录跳转
     * @throws AuthenticationException
     */
    public function unauthorized()
    {
        throw new AuthenticationException('Unauthorized.');
    }
}
