<?php
declare(strict_types = 1);

namespace App\Http\Logics\Registration;

use App\Exceptions\GeneralException;
use App\Services\HisHttp\Client;
use App\Utils\Traits\Logger;
use Illuminate\Support\Facades\Redis;
use Symfony\Component\HttpFoundation\Response;

class ScheduleLogic
{
    use Logger;

    private Client $his_client;

    /**
     * PatientLogic Construct
     */
    public function __construct()
    {
        $this->his_client = app('HisHttpService');
    }

    /**
     * 获取科室列表
     * @param string $date
     * @return array
     * @throws GeneralException
     */
    public function getDeptLists(string $date): array
    {
        $response = $this->his_client->getDepType('', '','01', $date);

        if (!isset($response['success']) || !$response['success']) {
            throw new GeneralException($response['msg'] ?? '暂无科室排班！', Response::HTTP_SERVICE_UNAVAILABLE);
        }

        Redis::setex('departments.'. $date, 2 * 3600, json_encode($response, JSON_UNESCAPED_UNICODE));

        return $response;
    }

    /**
     * 获取医生列表
     * @param string $date 日期
     * @param string $dept_id 科室ID
     * @return array
     * @throws GeneralException
     */
    public function getDoctorLists(string $date, string $dept_id): array
    {
        $type = $date === date('Y-m-d') ? '3' : '1';

        $response = $this->his_client->getDoctorLists($dept_id, $type, '', $date);
        if (!isset($response['success']) || !$response['success']) {
            throw new GeneralException($response['msg'] ?? '该科室暂无医生排班！', Response::HTTP_SERVICE_UNAVAILABLE);
        }

        return $response;
    }
}
