<?php

declare(strict_types=1);

namespace UnifyPayment\Cores\Struct;

use InvalidArgumentException;
use UnifyPayment\Cores\Traits\Arrayable;

/**
 * Struct ConfirmOrderForEx.
 */
class ConfirmOrderForEx
{
    use Arrayable;

    /**
     * @var string
     */
    public string $orderNo;

    /**
     * @var string
     */
    public string $hisSerialNo;

    /**
     * @var string
     */
    public string $payAccount;

    /**
     * @var string
     */
    public string $transNo;

    /**
     * ConfirmOrderForEx construct.
     *
     * @param string $orderNo
     * @param string $hisSerialNo
     */
    public function __construct(
        string $orderNo = '',
        string $hisSerialNo = '',
        string $payAccount = '',
        string $transNo = ''
    ) {
        $this->setOrderNo($orderNo)
            ->setHisSerialNo($hisSerialNo)
            ->setPayAccount($payAccount)
            ->setTransNo($transNo);
    }

    /**
     * Get orderNo value
     *
     * @return string|null
     */
    public function getOrderNo(): string
    {
        return $this->orderNo;
    }

    /**
     * Set orderNo value
     *
     * @param string $orderNo
     *
     * @return ConfirmOrderForEx
     */
    public function setOrderNo(string $orderNo = ''): ConfirmOrderForEx
    {
        // validation for constraint: string
        if (!is_string($orderNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($orderNo, true),
                    gettype($orderNo)
                ), __LINE__
            );
        }

        $this->orderNo = $orderNo;
        return $this;
    }

    /**
     * Get hisSerialNo value
     *
     * @return string|null
     */
    public function getHisSerialNo(): string
    {
        return $this->hisSerialNo;
    }

    /**
     * Set hisSerialNo value
     *
     * @param string $hisSerialNo
     *
     * @return ConfirmOrderForEx
     */
    public function setHisSerialNo(string $hisSerialNo = ''): ConfirmOrderForEx
    {
        // validation for constraint: string
        if (!is_string($hisSerialNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($hisSerialNo, true),
                    gettype($hisSerialNo)
                ), __LINE__
            );
        }

        $this->hisSerialNo = $hisSerialNo;
        return $this;
    }

    /**
     * Get payAccount value
     *
     * @return string|null
     */
    public function getPayAccount(): string
    {
        return $this->payAccount;
    }

    /**
     * Set payAccount value
     *
     * @param string $payAccount
     *
     * @return ConfirmOrderForEx
     */
    public function setPayAccount(string $payAccount = ''): ConfirmOrderForEx
    {
        // validation for constraint: string
        if (!is_string($payAccount)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($payAccount, true),
                    gettype($payAccount)
                ), __LINE__
            );
        }

        $this->payAccount = $payAccount;
        return $this;
    }

    /**
     * Get transNo value
     *
     * @return string|null
     */
    public function getTransNo(): string
    {
        return $this->transNo;
    }

    /**
     * Set transNo value
     *
     * @param string $transNo
     *
     * @return ConfirmOrderForEx
     */
    public function setTransNo(string $transNo = ''): ConfirmOrderForEx
    {
        // validation for constraint: string
        if (!is_string($transNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($transNo, true),
                    gettype($transNo)
                ), __LINE__
            );
        }

        $this->transNo = $transNo;
        return $this;
    }
}