<?php

declare(strict_types=1);

namespace UnifyPayment\Cores\Struct;

use InvalidArgumentException;
use UnifyPayment\Cores\Traits\Arrayable;

/**
 * Struct CreateWeChatOrders.
 */
class CreateOrder
{
    use Arrayable;

    /**
     * @var string
     */
    public string $title;

    /**
     * @var string
     */
    public string $orderNo;

    /**
     * @var string
     */
    public string $amount;

    /**
     * @var string
     */
    public string $tag;

    /**
     * @var string
     */
    public string $attach;

    /**
     * @var string
     */
    public string $orderType;

    /**
     * @var string
     */
    public string $openId;

    /**
     * @var string
     */
    public string $notifyUrl;

    /**
     * @param string $title
     * @param string $orderNo
     * @param string $amount
     * @param string $tag
     * @param string $attach
     * @param string $orderType
     * @param string $openId
     * @param string $notifyUrl
     */
    public function __construct(
        string $title = '',
        string $orderNo = '',
        string $amount = '0',
        string $tag = '',
        string $attach = '',
        string $orderType = '',
        string $openId = '',
        string $notifyUrl = ''
    ) {
        $this->setTitle($title)
            ->setOrderNo($orderNo)
            ->setAmount($amount)
            ->setTag($tag)
            ->setAttach($attach)
            ->setOrderType($orderType)
            ->setOpenId($openId)
            ->setNotifyUrl($notifyUrl);
    }

    /**
     * Get title value
     *
     * @return string|null
     */
    public function getTitle(): string
    {
        return $this->title;
    }

    /**
     * Set title value
     *
     * @param string $title
     *
     * @return CreateOrder
     */
    public function setTitle(string $title = ''): CreateOrder
    {
        // validation for constraint: string
        if (!is_string($title)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($title, true),
                    gettype($title)
                ), __LINE__
            );
        }

        $this->title = $title;
        return $this;
    }

    /**
     * Get orderNo value
     *
     * @return string|null
     */
    public function getOrderNo(): string
    {
        return $this->orderNo;
    }

    /**
     * Set title value
     *
     * @param string $orderNo
     *
     * @return CreateOrder
     */
    public function setOrderNo(string $orderNo = ''): CreateOrder
    {
        // validation for constraint: string
        if (!is_string($orderNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($orderNo, true),
                    gettype($orderNo)
                ), __LINE__
            );
        }

        $this->orderNo = $orderNo;
        return $this;
    }

    /**
     * Get mount value
     *
     * @return string|null
     */
    public function getAmount(): string
    {
        return $this->amount;
    }

    /**
     * Set mount value
     *
     * @param float $mount
     *
     * @return CreateOrder
     */
    public function setAmount(string $mount = '0'): CreateOrder
    {
        // validation for constraint: falot
        if (!is_string($mount)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($mount, true),
                    gettype($mount)
                ), __LINE__
            );
        }

        $this->amount = $mount;
        return $this;
    }

    /**
     * Get tag value
     *
     * @return string|null
     */
    public function getTag(): string
    {
        return $this->tag;
    }

    /**
     * Set tag value
     *
     * @param string $tag
     *
     * @return CreateOrder
     */
    public function setTag(string $tag = ''): CreateOrder
    {
        // validation for constraint: string
        if (!is_string($tag)) {
            throw new InvalidArgumentException(
                sprintf('Invalid value %s, please provide a string, %s given', var_export($tag, true), gettype($tag)),
                __LINE__
            );
        }

        $this->tag = $tag;
        return $this;
    }

    /**
     * Get attach value
     *
     * @return string|null
     */
    public function getAttach(): string
    {
        return $this->attach;
    }

    /**
     * Set attach value
     *
     * @param string $attach
     *
     * @return CreateOrder
     */
    public function setAttach(string $attach = ''): CreateOrder
    {
        // validation for constraint: string
        if (!is_string($attach)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($attach, true),
                    gettype($attach)
                ), __LINE__
            );
        }

        $this->attach = $attach;
        return $this;
    }

    /**
     * Get orderType value
     *
     * @return string|null
     */
    public function getOrderType(): string
    {
        return $this->orderType;
    }

    /**
     * Set orderType value
     *
     * @param string $orderType
     *
     * @return CreateOrder
     */
    public function setOrderType(string $orderType = ''): CreateOrder
    {
        // validation for constraint: string
        if (!is_string($orderType)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($orderType, true),
                    gettype($orderType)
                ), __LINE__
            );
        }

        $this->orderType = $orderType;
        return $this;
    }

    /**
     * Get openId value
     *
     * @return string|null
     */
    public function getOpenId(): string
    {
        return $this->openId;
    }

    /**
     * Set openId value
     *
     * @param string $openId
     *
     * @return CreateOrder
     */
    public function setOpenId(string $openId = ''): CreateOrder
    {
        // validation for constraint: string
        if (!is_string($openId)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($openId, true),
                    gettype($openId)
                ), __LINE__
            );
        }

        $this->openId = $openId;
        return $this;
    }

    /**
     * Get notifyUrl value
     *
     * @return string|null
     */
    public function getNotifyUrl(): string
    {
        return $this->notifyUrl;
    }

    /**
     * Set notifyUrl value
     *
     * @param string $notifyUrl
     *
     * @return CreateOrder
     */
    public function setNotifyUrl(string $notifyUrl = ''): CreateOrder
    {
        // validation for constraint: string
        if (!is_string($notifyUrl)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($notifyUrl, true),
                    gettype($notifyUrl)
                ), __LINE__
            );
        }

        $this->notifyUrl = $notifyUrl;
        return $this;
    }
}