<?php

declare(strict_types=1);

namespace UnifyPayment;

use UnifyPayment\Cores\Config;
use UnifyPayment\Cores\Exceptions\ClassNotExistsException;
use UnifyPayment\Cores\Log;
use UnifyPayment\Cores\Support\Logger;
use UnifyPayment\Cores\Support\Str;

/**
 * @method static Modules\Common\Application  common(array $config)  公共类
 * @method static Modules\Pay\Application     pay(array $config) 支付类
 */
class Factory
{

    protected Config $config;

    public function __construct(array $config)
    {
        $this->config = new Config($config);

        $this->registerLogService();
    }

    /**
     * Dynamically pass methods to the application.
     * @param string $name
     * @param array $arguments
     * @return mixed
     * @throws ClassNotExistsException
     */
    public function __call(string $name, array $arguments)
    {
        return $this->make($name);
    }

    /**
     * Dynamically pass methods to the application.
     *
     * @param string $name
     * @param array  $arguments
     *
     * @return mixed
     *
     * @throws ClassNotExistsException
     */
    public static function __callStatic(string $name, array $arguments)
    {
        return (new self(... $arguments))->make($name);
    }

    /**
     * Make Application.
     *
     * @param string $name
     *
     * @return mixed
     *
     * @throws ClassNotExistsException
     */
    public function make(string $name)
    {
        $namespace = Str::studly($name);
        $application = "\\UnifyPayment\\Modules\\{$namespace}\\Application";

        if (!class_exists($application)) {
            throw new ClassNotExistsException("Class [{$name}] Not Exists");
        }

        return new $application($this->config);
    }

    /**
     * Register log Service
     *
     * @return void
     */
    public function registerLogService(): void
    {
        $logger = new Logger();
        $logger->setConfig($this->config->get('log'));

        Log::setInstance($logger);
    }
}
