<?php

declare(strict_types=1);

namespace UnifyPayment\Modules\Common;

use ReflectionException;
use UnifyPayment\Cores\BasicClient;
use UnifyPayment\Cores\Struct\ConfirmOrderForEx;
use UnifyPayment\Cores\Struct\QueryOrder;
use UnifyPayment\Cores\Struct\RefundOrder;
use UnifyPayment\Cores\Struct\CloseOrder;

class OrderClient extends BasicClient
{

    /**
     * Query Order.
     *
     * @param QueryOrder $order
     *
     * @return array|string
     *
     * @throws ReflectionException
     */
    public function query(QueryOrder $order)
    {
        $this->payload = array_merge($this->payload, $order->toArray());
        $this->payload['apiSecret'] = $this->config->get('apiSecret');

        return $this->request('post', '/index.php/api/pay/query');
    }

    /**
     * Close Order.
     *
     * @param CloseOrder $order
     *
     * @return array|string
     *
     * @throws ReflectionException
     */
    public function close(CloseOrder $order)
    {
        $this->payload = array_merge($this->payload, $order->toArray());
        $this->payload['apiSecret'] = $this->config->get('apiSecret');

        return $this->request('post', '/index.php/api/pay/close');
    }


    /**
     * Refund Order.
     *
     * @param RefundOrder $order
     *
     * @return array|string
     *
     * @throws ReflectionException
     */
    public function refund(RefundOrder $order)
    {
        $this->payload = array_merge($this->payload, $order->toArray());
        $this->payload['apiSecret'] = $this->config->get('apiSecret');

        return $this->request('post', '/index.php/api/pay/refund');
    }

    /**
     * Confirm Order For Extends.
     *
     * @param ConfirmOrderForEx $order
     *
     * @return array|string
     *
     * @throws ReflectionException
     */
    public function confirmForEx(ConfirmOrderForEx $order)
    {
        $this->payload = array_merge($this->payload, $order->toArray());
        $this->payload['apiSecret'] = $this->config->get('apiSecret');

        return $this->request('post', '/index.php/api/pay/confirmForEx');
    }
}